@@ -1,4 +1,4 @@
-//(Automatic CVS control) $Revision: 1.6 $ $Date: 2003/09/17 09:10:35 $
+//(Automatic CVS control) $Revision: 1.7.2.1 $ $Date: 2004/07/31 00:53:04 $
 
 /*
 ------------------------------------------------------------------------
@@ -24,7 +24,7 @@ using namespace std;
 // create decimal constants from digits at choosen base x
 template <unsigned base, unsigned digits>
 inline unsigned convert_base() {
-    return digits ? (base * convert_base<base,digits/10>() + digits%10) : 0 ;
+    return digits ? (base * convert_base<base,(digits/10)>() + digits%10) : 0 ;
 }
 
 int main() {
